#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_GROUP_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_GROUP_HPP_INCLUDED

#include <boost/simd/swar/include/functions/simd/group.hpp>

#endif
